(* ::Package:: *)

?R


(*:Copyright: Copyright 1988-2003 Wolfram Research, Inc. *)

(*:Mathematica Version: 3.0 *)

(*:Package Version: 1.0 *)

(*:Name: Algebra`g2` *)

(*:Title: g_2 exceptional Lie algebra *) 

(*:Author: C\[AAcute]ndido Mart\[IAcute]n Gonz\[AAcute]lez *)

(*:Keywords: exceptional Lie algebra *)

(* :Sources: Multi-source package*)

(*:Summary:
Package for computations in g_2*)

BeginPackage["Algebra`g2`"]

c::usage = "Gives the Lie bracket x.y-y.x of two elements x and y."
d::usage = "General derivation of Zorn's Matrices algebra."
h::usage = "h_i, i=1,2 generate a Cartan subalgebra of g_2."
sh::usage = "generator of root space of a short root."
lo::usage = "generator of root space of a long root."
RootSystem::usage ="Asigns a root system to vectors v_{a_i}."
TorusCay::usage = "Maximal torus in G_2=Aut(Cay)."

Begin["Algebra`g2`Private`"]

c[x_,y_]:=Expand[x.y-y.x];

d[a_]:={{0,0,Subscript[a,6,2],Subscript[a,7,2],Subscript[a,8,2],-Subscript[a,8,4],
    Subscript[a,8,3],-Subscript[a,7,3]},{0,
    0,-Subscript[a,6,2],-Subscript[a,7,2],-Subscript[a,8,2],
    Subscript[a,8,4],-Subscript[a,8,3],
    Subscript[a,7,3]},{Subscript[a,8,4],-Subscript[a,8,4],
    Subscript[a,7,7]+Subscript[a,8,8],-Subscript[a,7,6],-Subscript[a,8,6],0,
    Subscript[a,8,2],-Subscript[a,7,2]},{-Subscript[a,8,3],
    Subscript[a,8,
      3],-Subscript[a,6,7],-Subscript[a,7,7],-Subscript[a,8,7],-Subscript[a,8,
        2],0,Subscript[a,6,2]},{Subscript[a,7,
      3],-Subscript[a,7,3],-Subscript[a,6,8],-Subscript[a,7,8],-Subscript[a,8,
        8],Subscript[a,7,2],-Subscript[a,6,2],0},{-Subscript[a,6,2],
    Subscript[a,6,2],
    0,-Subscript[a,7,3],-Subscript[a,8,3],-Subscript[a,7,7]-Subscript[a,8,8],
    Subscript[a,6,7],Subscript[a,6,8]},{-Subscript[a,7,2],Subscript[a,7,2],
    Subscript[a,7,3],0,-Subscript[a,8,4],Subscript[a,7,6],Subscript[a,7,7],
    Subscript[a,7,8]},{-Subscript[a,8,2],Subscript[a,8,2],Subscript[a,8,3],
    Subscript[a,8,4],0,Subscript[a,8,6],Subscript[a,8,7],Subscript[a,8,8]}}

Subscript[h,1]={{0,0,0,0,0,0,0,0},{0,0,0,0,0,0,0,0},{0,0,1,0,0,0,0,0},{0,0,0,-1,0,0,0,0},{0,
    0,0,0,0,0,0,0},{0,0,0,0,0,-1,0,0},{0,0,0,0,0,0,1,0},{0,0,0,0,0,0,0,0}}
    
Subscript[h,2]={{0,0,0,0,0,0,0,0},{0,0,0,0,0,0,0,0},{0,0,1,0,0,0,0,0},{0,0,0,0,0,0,0,0},{0,0,
    0,0,-1,0,0,0},{0,0,0,0,0,-1,0,0},{0,0,0,0,0,0,0,0},{0,0,0,0,0,0,0,1}}
    
lo={{0,0,0,0,0,0,0,0},{0,0,0,0,0,0,0,0},{0,0,0,0,0,0,0,0},{0,0,-1,0,0,0,0,0},{0,
    0,0,0,0,0,0,0},{0,0,0,0,0,0,1,0},{0,0,0,0,0,0,0,0},{0,0,0,0,0,0,0,0}}

sh={{0,0,0,1,0,0,0,0},{0,0,0,-1,0,0,0,0},{0,0,0,0,0,0,0,-1},{0,0,0,0,0,0,0,0},{0,
    0,0,0,0,1,0,0},{0,0,0,0,0,0,0,0},{-1,1,0,0,0,0,0,0},{0,0,0,0,0,0,0,0}}

RootSystem[v_,a_]:=(
Subscript[v,Subscript[a,1]]=lo;
Subscript[v,-Subscript[a,1]]=Transpose[lo];          
Subscript[v,Subscript[a,2]]=sh;
Subscript[v,-Subscript[a,2]]=Transpose[sh];
Subscript[v,Subscript[a,1]+Subscript[a,2]]=c[lo,sh];
Subscript[v,-Subscript[a,1]-Subscript[a,2]]=Transpose[c[lo,sh]];
Subscript[v,Subscript[a,1]+2 Subscript[a,2]]=c[c[lo,sh],sh];
Subscript[v,-Subscript[a,1]-2 Subscript[a,2]]=Transpose[c[c[lo,sh],sh]];
Subscript[v,Subscript[a,1]+3 Subscript[a,2]]=c[c[c[lo,sh],sh],sh];
Subscript[v,-Subscript[a,1]-3 Subscript[a,2]]=Transpose[c[c[c[lo,sh],sh],sh]];
Subscript[v,2 Subscript[a,1]+3 Subscript[a,2]]=c[lo,c[c[c[lo,sh],sh],sh]];
Subscript[v,-2 Subscript[a,1]-3 Subscript[a,2]]=Transpose[c[lo,c[c[c[lo,sh],sh],sh]]];
)v

TorusCay[a_,b_]:={{1,0,0,0,0,0,0,0},
{0,1,0,0,0,0,0,0},
{0,0,a,0,0,0,0,0},
{0,0,0,b,0,0,0,0},
{0,0,0,0,1/(a*b),0,0,0},
{0,0,0,0,0,1/a,0,0},
{0,0,0,0,0,0,1/b,0},
{0,0,0,0,0,0,0,a*b}}

End[]  (* Algebra`g2`Private` *)



EndPackage[]  (* Algebra`g2` *)

            
